#' Heart Disease Data
#'
#' There are variables related to patient clinic trial. The variable to predict is `has_heart_disease`.
#'
#' @format A data frame with 303 rows and 16 variables:
#' \itemize{
#'
#'    \url{https://archive.ics.uci.edu/ml/datasets/Heart+Disease}
#' }
"heart_disease"

#' People with flu data
#'
#' Each row represents a person from different countries indicating if he or she has or not flu.
#' Colmuns
#' person: unique id
#' country: country of the person, 70 different countries
#' has_flu: character variable with values "yes" or "no" indicating if the person has flu
#'
#' @format A data frame with 910 rows and 3 variables
#'
"data_country"

#' Play golf
#'
#' This well known small data frame containst 14 cases indicating wheter or not play golf based on wheather conditions. Target variable: 'play_golf.'
#'
#' @format A data frame with 14 rows and 3 variables
#'
"data_golf"
